"""
Django Automated Logging makes logging easy.

Django Automated Logging (DAL) is a package with the purpose of
making logging in django automated and easy.
"""
default_app_config = 'automated_logging.apps.AutomatedloggingConfig'
